@@ -3,8 +3,6 @@
 from dataclasses import dataclass
 from typing import TYPE_CHECKING
 
-from chip.clusters import Attribute
-
 from .node import MatterNode
 
 
@@ -16,6 +14,8 @@ class ServerInfo:
     compressed_fabric_id: int
     schema_version: int
     sdk_version: str
+    wifi_credentials_set: bool
+    thread_credentials_set: bool
 
 
 @dataclass
@@ -24,4 +24,4 @@ class ServerDiagnostics:
 
     info: ServerInfo
     nodes: list[MatterNode]
-    events: list[Attribute.EventReadResult]
+    events: list[dict]  # TODO !
